@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2017, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -9,14 +9,15 @@
 !
 !  Include file for Fortran use of the EPS object in SLEPc
 !
-#if !defined(__SLEPCEPSDEF_H)
-#define __SLEPCEPSDEF_H
+#if !defined(SLEPCEPSDEF_H)
+#define SLEPCEPSDEF_H
 
 #include "slepc/finclude/slepcsys.h"
 #include "slepc/finclude/slepcst.h"
 #include "slepc/finclude/slepcbv.h"
 #include "slepc/finclude/slepcds.h"
 #include "slepc/finclude/slepcrg.h"
+#include "slepc/finclude/slepclme.h"
 #include "petsc/finclude/petscsnes.h"
 
 #define EPS type(tEPS)
@@ -46,6 +47,7 @@
 #define EPSRQCG        'rqcg'
 #define EPSLOBPCG      'lobpcg'
 #define EPSCISS        'ciss'
+#define EPSLYAPII      'lyapii'
 #define EPSLAPACK      'lapack'
 #define EPSARPACK      'arpack'
 #define EPSBLZPACK     'blzpack'
@@ -53,6 +55,8 @@
 #define EPSBLOPEX      'blopex'
 #define EPSPRIMME      'primme'
 #define EPSFEAST       'feast'
+#define EPSSCALAPACK   'scalapack'
+#define EPSELEMENTAL   'elemental'
 
 #endif
 
